@@ -227,6 +227,10 @@ def plot_pulls(**kwargs):
               help='Offset likelihood')
 @click.option('--optimize', type=int, default=2, show_default=True,
               help='Optimize constant terms')
+@click.option('--improve', type=int, default=0, show_default=True,
+              help='Execute improve after each minimization')
+@click.option('--minimizer_offset', type=int, default=1, show_default=True,
+              help='Enable minimizer offsetting')
 @click.option('--fix-cache/--no-fix-cache', default=True, show_default=True,
               help='Fix StarMomentMorph cache')
 @click.option('--fix-multi/--no-fix-cache',  default=True, show_default=True,
