@@ -20,11 +20,10 @@ class AnalysisObject(AbstractObject):
                  minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', precision:float=0.001, 
                  eps:float=1.0, retry:int=1, strategy:int=1, print_level:int=-1, timer:bool=False,
                  num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False, hesse:bool=False,
-                 fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
+                 improve:int=0, fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
-                 int_bin_precision:float=-1., preset_param:bool=False,
-                 minimizer_cls=None,
-                 verbosity:Optional[Union[int, str]]="INFO"):
+                 int_bin_precision:float=-1., preset_param:bool=False, minimizer_offset:int=1,
+                 minimizer_cls=None, verbosity:Optional[Union[int, str]]="INFO"):
         super().__init__(verbosity=verbosity)    
         self.model = None
         self.minimizer = None
@@ -42,10 +41,30 @@ class AnalysisObject(AbstractObject):
             if preset_param:
                 self.preset_parameters()
             self.setup_parameters(fix_param, profile_param, update_snapshot=True)
-            self.setup_minimizer(minimizer_type, minimizer_algo, precision, eps, retry, strategy,
-                                 num_cpu, offset, optimize, eigen, hesse, max_calls, max_iters, print_level,
-                                 timer, constrain_nuis, batch_mode, int_bin_precision,
-                                 verbosity=verbosity)
+            minimizer_options = {
+                "minimizer_type"    : minimizer_type,
+                "minimizer_algo"    : minimizer_algo,
+                "precision"         : precision,
+                "eps"               : eps,
+                "retry"             : retry,
+                "strategy"          : strategy,
+                "num_cpu"           : num_cpu,
+                "offset"            : offset,
+                "minimizer_offset"  : minimizer_offset,
+                "optimize"          : optimize,
+                "eigen"             : eigen,
+                "hesse"             : hesse,
+                "improve"           : improve,
+                "max_calls"         : max_calls,
+                "max_iters"         : max_iters,
+                "print_level"       : print_level,
+                "timer"             : timer,
+                "constrain_nuis"    : constrain_nuis,
+                "batch_mode"        : batch_mode,
+                "int_bin_precision" : int_bin_precision,
+                "verbosity"         : verbosity
+            }
+            self.setup_minimizer(**minimizer_options)
             self.sanity_check()
         
     def sanity_check(self):
@@ -170,11 +189,13 @@ class AnalysisObject(AbstractObject):
     def setup_minimizer(self, minimizer_type:str='Minuit2', minimizer_algo:str='Migrad', 
                         precision:float=0.001, eps:float=1.0, retry:int=1, strategy:int=0, 
                         num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
-                        hesse:bool=False, max_calls:int=-1, max_iters:int=-1, print_level:int=-1,
-                        timer:bool=False, constrain_nuis:bool=True, batch_mode:bool=False,
-                        int_bin_precision:float=-1., verbosity:Optional[Union[int, str]]="INFO"):
+                        hesse:bool=False, improve:int=0, max_calls:int=-1, max_iters:int=-1,
+                        print_level:int=-1, timer:bool=False, constrain_nuis:bool=True,
+                        batch_mode:bool=False, int_bin_precision:float=-1., minimizer_offset:int=1,
+                        verbosity:Optional[Union[int, str]]="INFO"):
         
-        minimizer = self.minimizer_cls("Minimizer", self.model.pdf, self.model.data, verbosity=verbosity)
+        minimizer = self.minimizer_cls("Minimizer", self.model.pdf, self.model.data,
+                                       workspace=self.model.workspace, verbosity=verbosity)
         
         nll_options = {
             "num_cpu": num_cpu,
@@ -200,6 +221,8 @@ class AnalysisObject(AbstractObject):
             'retry'            : retry,
             'eigen'            : eigen,
             'hesse'            : hesse,
+            'minimizer_offset' : minimizer_offset,
+            'improve'          : improve,
             'max_calls'        : max_calls,
             'max_iters'        : max_iters,
             'print_level'      : print_level,
