@@ -8,10 +8,14 @@ class RooProcGlobalVariables(RooProcHelperAction):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         
+    def commarepl(matchobj):
+        return matchobj.group(0).replace(",", "::COMMA::")        
+        
     @classmethod
     def parse(cls, main_text:str, block_text:Optional[str]=None):
         main_text = re.sub(r"\s*", "", main_text)
-        tokens = main_text.split(",")
+        main_text = re.sub(r'\[(.*?)\]', cls.commarepl, main_text)
+        tokens = [token.replace("::COMMA::", ",") for token in main_text.split(",")]
         global_variables = {}
         for token in tokens:
             result = re.match("^(\w+)=(.*)", token)
