@@ -32,10 +32,12 @@ class WSItemType(GeneralEnum):
     VARIABLE = (2, kName|kValue|kExtras   , kSingleLine)
     OTHER    = (3, 0                      , kSingleLine)
     
-    def __init__(self, enum_id:int, default_content:int, default_style:int):
-        self.enum_id         = enum_id
-        self.default_content = default_content
-        self.default_style   = default_style
+    def __new__(cls, value:int, default_content:int, default_style:int):
+        obj = object.__new__(cls)
+        obj._value_ = value
+        obj.default_content = default_content
+        obj.default_style = default_style
+        return obj
     
 class WSItem(GeneralEnum):
     
@@ -57,15 +59,17 @@ class WSItem(GeneralEnum):
     AUXILIARY                        = (11, WSItemType.VARIABLE, 'Auxiliary Variables',
                                         WSArgument.AUXILIARY, True, False, 0b01011)
     
-    def __init__(self, enum_id:int, item_type:WSItemType, title:str, var_repr:Optional[WSArgument],
-                 support_definition:bool, is_composite:bool, default_visibility:int):
-        self.enum_id   = enum_id
-        self.item_type = item_type
-        self.title     = title
-        self.var_repr  = var_repr
-        self.support_definition = support_definition
-        self.is_composite = is_composite
-        self.default_visibility = default_visibility
+    def __new__(cls, value:int, item_type:WSItemType, title:str, var_repr:Optional[WSArgument],
+                support_definition:bool, is_composite:bool, default_visibility:int):
+        obj = object.__new__(cls)
+        obj._value_ = value
+        obj.item_type = item_type
+        obj.title     = title
+        obj.var_repr  = var_repr
+        obj.support_definition = support_definition
+        obj.is_composite = is_composite
+        obj.default_visibility = default_visibility
+        return obj
             
 class ComparisonData:
 
