@@ -19,7 +19,7 @@ class ParameterisedLikelihood(ParameterisedRunner):
     def __init__(self, input_file:str, param_expr:str,
                  filter_expr:Optional[str]=None, exclude_expr:Optional[str]=None,
                  data_name:str="combData", uncond_snapshot:Optional[str]=None,
-                 config:Optional[Dict]=None, outdir:str="output",
+                 config:Optional[Dict]=None, outdir:str="output", cachedir:str="cache",
                  outname:str="{poi_names}.json", cache:bool=True,
                  save_log:bool=True, parallel:int=-1,
                  verbosity:Optional[Union[int, str]]="INFO"):
@@ -35,6 +35,7 @@ class ParameterisedLikelihood(ParameterisedRunner):
             'uncond_snapshot': uncond_snapshot,
             'config': config,
             'outdir': outdir,
+            'cachedir': cachedir,
             'outname': outname
         }
         
@@ -116,7 +117,7 @@ class ParameterisedLikelihood(ParameterisedRunner):
             return None
         
     def get_cache_dir(self):
-        return os.path.join(self.attributes['outdir'], 'cache')
+        return os.path.join(self.attributes['outdir'], self.attributes['cachedir'])
     
     def prepare_task_inputs(self):
         
