@@ -15,6 +15,8 @@ class GeneralEnum(Enum):
     def parse(cls, expr:str):
         if isinstance(expr, cls):
             return expr
+        elif isinstance(expr, int):
+            return cls(expr)
         _expr = expr.strip().upper()
         if _expr in cls.__members__:
             return cls[_expr]
@@ -28,10 +30,13 @@ class GeneralEnum(Enum):
         return [i.lower() for i in cls.__members__]
     
 class DescriptiveEnum(GeneralEnum):
-    def __init__(self, enum_id:int, description:str=""):
-        self.enum_id = enum_id
-        self.description = description
-        
+    
+    def __new__(cls, value:int, description:str=""):
+        obj = object.__new__(cls)
+        obj._value_ = value
+        obj.description = description
+        return obj
+
     @classmethod
     def on_parse_exception(cls, expr:str):
         enum_descriptions = "".join([f"    {key.lower()} - {val.description}\n" \
