@@ -99,7 +99,7 @@ class RooDataSet:
     
     @semistaticmethod
     def to_pandas(self, dataset:"ROOT.RooDataSet"):
-        numpy_data = self.to_numpy(dataset, reduced=reduced)
+        numpy_data = self.to_numpy(dataset)
         import pandas as pd
         df = pd.DataFrame(numpy_data)
         return df
