@@ -72,6 +72,9 @@ class UpperLimit1DPlot(AbstractPlot):
         self.labels = combine_dict(self.LABELS, labels)
         self.config = combine_dict(self.CONFIG, config)
 
+    def get_default_legend_order(self):
+        return ["observed", "expected", "third", "one_sigma", "two_sigma", "curve"]        
+
     def add_curve(self, x, xerrlo=None, xerrhi=None,
                   label: str = "Theory prediction",
                   line_styles: Optional[Dict] = None,
@@ -129,16 +132,19 @@ class UpperLimit1DPlot(AbstractPlot):
             # draw observed
             if draw_observed:
                 observed_limit = df['obs']
-                ax.vlines(observed_limit, i, i+1, colors=self.color_pallete['observed'], linestyles='solid',
-                          zorder=1.1, label=self.labels['observed'] if i == 0 else '')
-                ax.scatter(observed_limit, i + 0.5, s=markersize, marker='o',
-                           color=self.color_pallete['observed'], zorder=1.1)
+                handle_1 = ax.vlines(observed_limit, i, i+1, colors=self.color_pallete['observed'], linestyles='solid',
+                                     zorder=1.1, label=self.labels['observed'] if i == 0 else '')
+                handle_2 = ax.scatter(observed_limit, i + 0.5, s=markersize, marker='o',
+                                      color=self.color_pallete['observed'], zorder=1.1)
+                observed_handle = (handle_1, handle_2)
                 if add_text:
                     ax.text(text_pos['observed'], i + 0.5, f"{{:.{sig_fig}f}}".format(observed_limit),
                             horizontalalignment='center',
                             verticalalignment='center',
                             transform=transform,
                             **self.styles['text'])
+            else:
+                observed_handle = None
             # draw stat
             if draw_stat:
                 stat_limit = df['stat']
@@ -150,8 +156,8 @@ class UpperLimit1DPlot(AbstractPlot):
                             **self.styles['text'])
             # draw expected
             expected_limit = df['0']
-            ax.vlines(expected_limit, i, i + 1, colors=self.color_pallete['expected'], linestyles='dotted',
-                      zorder=1.1, label=self.labels['expected'] if i == 0 else '')
+            expected_handle = ax.vlines(expected_limit, i, i + 1, colors=self.color_pallete['expected'], linestyles='dotted',
+                                        zorder=1.1, label=self.labels['expected'])
             if add_text:
                 ax.text(text_pos['expected'], i + 0.5, f"{{:.{sig_fig}f}}".format(expected_limit),
                         horizontalalignment='center',
@@ -161,19 +167,32 @@ class UpperLimit1DPlot(AbstractPlot):
             # draw third
             if draw_third_column:
                 third_limit = df['third']
-                ax.vlines(third_limit, i, i + 1, colors=self.color_pallete['third'], linestyles='dashed',
-                          zorder=1.1, label=self.labels['third'] if i == 0 else '')
+                third_handle = ax.vlines(third_limit, i, i + 1, colors=self.color_pallete['third'], linestyles='dashed',
+                                         zorder=1.1, label=self.labels['third'])
                 if add_text:
                     ax.text(text_pos['third'], i + 0.5, f"{{:.{sig_fig}f}}".format(third_limit),
                             horizontalalignment='center',
                             verticalalignment='center',
                             transform=transform,
                             **self.styles['text'])
+            else:
+                third_handle = None
             # draw error band
-            ax.fill_betweenx([i, i + 1], df['-2'], df['2'], facecolor=self.color_pallete['2sigma'],
-                             label=self.labels['2sigma'] if i == 0 else '')
-            ax.fill_betweenx([i, i + 1], df['-1'], df['1'], facecolor=self.color_pallete['1sigma'],
-                             label=self.labels['1sigma'] if i == 0 else '')
+            two_sigma_handle = ax.fill_betweenx([i, i + 1], df['-2'], df['2'], facecolor=self.color_pallete['2sigma'],
+                                                label=self.labels['2sigma'])
+            
+            one_sigma_handle = ax.fill_betweenx([i, i + 1], df['-1'], df['1'], facecolor=self.color_pallete['1sigma'],
+                                                label=self.labels['1sigma'])
+            if i == 0:
+                handles = {
+                    "expected": expected_handle,
+                    "one_sigma": one_sigma_handle,
+                    "two_sigma": two_sigma_handle,
+                }
+                for key, handle in [("observed", observed_handle), ("third", third_handle)]:
+                    if handle is not None:
+                        handles[key] = handle
+                self.update_legend_handles(handles)
         xlim = ax.get_xlim()
         ax.set_xlim(xlim[0] - (xlim[1]/0.7 - xlim[1])*0.5, xlim[1]/0.7)
         ax.set_ylim(0, len(self.category_df.columns) +
@@ -223,26 +242,8 @@ class UpperLimit1DPlot(AbstractPlot):
         if xlabel is not None:
             ax.set_xlabel(xlabel, **self.styles['xlabel'])
         # border for the legend
-        border_leg = patches.Rectangle(
-            (0, 0), 1, 1, facecolor='none', edgecolor='black', linewidth=1)
-
-        handles, labels = ax.get_legend_handles_labels()
-        if draw_observed and not draw_third_column:
-            handles = [handles[0], handles[1],
-                       (handles[3], border_leg), (handles[2], border_leg)]
-            labels = [labels[0], labels[1], labels[3], labels[2]]
-        if draw_stat and not draw_third_column:
-            handles = [handles[0], (handles[2], border_leg),
-                       (handles[1], border_leg)]
-            labels = [labels[0], labels[2], labels[1]]
-        if draw_third_column:
-            handles = [handles[0], handles[1],
-                       (handles[4], border_leg), (handles[3], border_leg), handles[2]]
-            labels = [labels[0], labels[1], labels[4], labels[3], labels[2]]
-        if self.curve_data is not None:
-            if isinstance(self.legend_data['curve']['handle'], tuple):
-                handles.append(
-                    (*self.legend_data['curve']['handle'], border_leg))
-                labels.append(self.legend_data['curve']['label'])
+        border_leg = patches.Rectangle( (0, 0), 1, 1, facecolor='none', edgecolor='black', linewidth=1)
+        self.add_legend_decoration(border_leg, targets=["one_sigma", "two_sigma", "curve"])
+        handles, labels = self.get_legend_handles_labels()
         ax.legend(handles, labels, **self.styles['legend'])
         return ax
